@@ -23,7 +23,7 @@ class TestFileDcx(PillowTestCase):
     def test_invalid_file(self):
         with open("Tests/images/flower.jpg", "rb") as fp:
             self.assertRaises(SyntaxError,
-                              lambda: DcxImagePlugin.DcxImageFile(fp))
+                              DcxImagePlugin.DcxImageFile, fp)
 
     def test_tell(self):
         # Arrange
@@ -42,15 +42,14 @@ class TestFileDcx(PillowTestCase):
 
     def test_eoferror(self):
         im = Image.open(TEST_FILE)
-
         n_frames = im.n_frames
-        while True:
-            n_frames -= 1
-            try:
-                im.seek(n_frames)
-                break
-            except EOFError:
-                self.assertTrue(im.tell() < n_frames)
+
+        # Test seeking past the last frame
+        self.assertRaises(EOFError, im.seek, n_frames)
+        self.assertLess(im.tell(), n_frames)
+
+        # Test that seeking to the last frame does not raise an error
+        im.seek(n_frames-1)
 
     def test_seek_too_far(self):
         # Arrange
@@ -58,7 +57,7 @@ class TestFileDcx(PillowTestCase):
         frame = 999  # too big on purpose
 
         # Act / Assert
-        self.assertRaises(EOFError, lambda: im.seek(frame))
+        self.assertRaises(EOFError, im.seek, frame)
 
 
 if __name__ == '__main__':
