@@ -9,7 +9,7 @@ class TestFileGbr(PillowTestCase):
         invalid_file = "Tests/images/flower.jpg"
 
         self.assertRaises(SyntaxError,
-                          lambda: GbrImagePlugin.GbrImageFile(invalid_file))
+                          GbrImagePlugin.GbrImageFile, invalid_file)
 
     def test_gbr_file(self):
         im = Image.open('Tests/images/gbr.gbr')
@@ -18,5 +18,6 @@ class TestFileGbr(PillowTestCase):
 
         self.assert_image_equal(target, im)
 
+
 if __name__ == '__main__':
     unittest.main()
