@@ -4,6 +4,8 @@ from PIL import Image
 from PIL import ImageSequence
 from PIL import SpiderImagePlugin
 
+import tempfile
+
 TEST_FILE = "Tests/images/hopper.spider"
 
 
@@ -30,6 +32,21 @@ class TestImageSpider(PillowTestCase):
         self.assertEqual(im2.size, (128, 128))
         self.assertEqual(im2.format, "SPIDER")
 
+    def test_tempfile(self):
+        # Arrange
+        im = hopper()
+
+        # Act
+        with tempfile.TemporaryFile() as fp:
+            im.save(fp, "SPIDER")
+
+            # Assert
+            fp.seek(0)
+            reloaded = Image.open(fp)
+            self.assertEqual(reloaded.mode, "F")
+            self.assertEqual(reloaded.size, (128, 128))
+            self.assertEqual(reloaded.format, "SPIDER")
+
     def test_isSpiderImage(self):
         self.assertTrue(SpiderImagePlugin.isSpiderImage(TEST_FILE))
 
@@ -69,7 +86,7 @@ class TestImageSpider(PillowTestCase):
         img_list = SpiderImagePlugin.loadImageSeries(file_list)
 
         # Assert
-        self.assertEqual(img_list, None)
+        self.assertIsNone(img_list)
 
     def test_isInt_not_a_number(self):
         # Arrange
@@ -84,12 +101,12 @@ class TestImageSpider(PillowTestCase):
     def test_invalid_file(self):
         invalid_file = "Tests/images/invalid.spider"
 
-        self.assertRaises(IOError, lambda: Image.open(invalid_file))
+        self.assertRaises(IOError, Image.open, invalid_file)
 
     def test_nonstack_file(self):
         im = Image.open(TEST_FILE)
 
-        self.assertRaises(EOFError, lambda: im.seek(0))
+        self.assertRaises(EOFError, im.seek, 0)
 
     def test_nonstack_dos(self):
         im = Image.open(TEST_FILE)
