@@ -1,4 +1,4 @@
-from helper import unittest, PillowTestCase, hopper
+from helper import unittest, PillowTestCase, hopper, on_appveyor
 
 try:
     from PIL import PyAccess
@@ -7,6 +7,8 @@ except ImportError:
     pass
 
 from PIL import Image
+import sys
+import os
 
 
 class AccessTest(PillowTestCase):
@@ -84,7 +86,7 @@ class TestImageGetPixel(AccessTest):
             im.putpixel((0, 0), c)
         with self.assertRaises(IndexError):
             im.getpixel((0, 0))
-            
+
         # check initial color
         im = Image.new(mode, (1, 1), c)
         self.assertEqual(
@@ -96,7 +98,6 @@ class TestImageGetPixel(AccessTest):
         with self.assertRaises(IndexError):
             im.getpixel((0, 0))
 
-
     def test_basic(self):
         for mode in ("1", "L", "LA", "I", "I;16", "I;16B", "F",
                      "P", "PA", "RGB", "RGBA", "RGBX", "CMYK", "YCbCr"):
@@ -234,6 +235,9 @@ class TestCffi(AccessTest):
         # im = Image.new('I;32B', (10, 10), 2**10)
         # self._test_set_access(im, 2**13-1)
 
+    def test_not_implemented(self):
+        self.assertIsNone(PyAccess.new(hopper("BGR;15")))
+
     # ref https://github.com/python-pillow/Pillow/pull/2009
     def test_reference_counting(self):
         size = 10
@@ -246,5 +250,66 @@ class TestCffi(AccessTest):
                 self.assertEqual(px[i, 0], 0)
 
 
+class TestEmbeddable(unittest.TestCase):
+    @unittest.skipIf(not sys.platform.startswith('win32') or
+                     sys.version_info[:2] == (3, 4) or
+                     on_appveyor(),   # failing on appveyor when run from
+                                      # subprocess, not from shell
+                     "requires Python 2.7 or >=3.5 for Windows")
+    def test_embeddable(self):
+        import subprocess
+        import ctypes
+        from distutils import ccompiler, sysconfig
+
+        with open('embed_pil.c', 'w') as fh:
+            fh.write("""
+#include "Python.h"
+
+int main(int argc, char* argv[])
+{
+    char *home = "%s";
+#if PY_MAJOR_VERSION >= 3
+    wchar_t *whome = Py_DecodeLocale(home, NULL);
+    Py_SetPythonHome(whome);
+#else
+    Py_SetPythonHome(home);
+#endif
+
+    Py_InitializeEx(0);
+    Py_DECREF(PyImport_ImportModule("PIL.Image"));
+    Py_Finalize();
+
+    Py_InitializeEx(0);
+    Py_DECREF(PyImport_ImportModule("PIL.Image"));
+    Py_Finalize();
+
+#if PY_MAJOR_VERSION >= 3
+    PyMem_RawFree(whome);
+#endif
+
+    return 0;
+}
+        """ % sys.prefix.replace('\\', '\\\\'))
+
+        compiler = ccompiler.new_compiler()
+        compiler.add_include_dir(sysconfig.get_python_inc())
+
+        libdir = sysconfig.get_config_var('LIBDIR') or sysconfig.get_python_inc().replace('include', 'libs')
+        print (libdir)
+        compiler.add_library_dir(libdir)
+        objects = compiler.compile(['embed_pil.c'])
+        compiler.link_executable(objects, 'embed_pil')
+
+        env = os.environ.copy()
+        env["PATH"] = sys.prefix + ';' + env["PATH"]
+
+        # do not display the Windows Error Reporting dialog
+        ctypes.windll.kernel32.SetErrorMode(0x0002)
+
+        process = subprocess.Popen(['embed_pil.exe'], env=env)
+        process.communicate()
+        self.assertEqual(process.returncode, 0)
+
+
 if __name__ == '__main__':
     unittest.main()
