@@ -1,10 +1,11 @@
 from helper import unittest, PillowTestCase
-
+from distutils.version import LooseVersion
 try:
     import numpy as np
     from numpy.testing import assert_equal
 
     from scipy import misc
+    import scipy
     HAS_SCIPY = True
 except ImportError:
     HAS_SCIPY = False
@@ -27,6 +28,11 @@ class Test_scipy_resize(PillowTestCase):
             im1 = misc.imresize(im, T(1.101))
             self.assertEqual(im1.shape, (11, 22))
 
+    # this test fails prior to scipy 0.14.0b1
+    # https://github.com/scipy/scipy/commit/855ff1fff805fb91840cf36b7082d18565fc8352
+    @unittest.skipIf(HAS_SCIPY and
+					 (LooseVersion(scipy.__version__) < LooseVersion('0.14.0')),
+                     "Test fails on scipy < 0.14.0")
     def test_imresize4(self):
         im = np.array([[1, 2],
                        [3, 4]])
