@@ -1,21 +1,13 @@
+#!/usr/bin/env python
 # minimal sanity check
 from __future__ import print_function
 
 import sys
 import os
 
-if "--installed" in sys.argv:
-    sys_path_0 = sys.path[0]
-    del sys.path[0]
-
 from PIL import Image, ImageDraw, ImageFilter, ImageMath
 from PIL import features
 
-if "--installed" in sys.argv:
-    sys.path.insert(0, sys_path_0)
-
-ROOT = "."
-
 try:
     Image.core.ping
 except ImportError as v:
@@ -50,13 +42,13 @@ def testimage():
 
     Or open existing files:
 
-    >>> im = Image.open(os.path.join(ROOT, "Tests/images/hopper.gif"))
+    >>> im = Image.open("Tests/images/hopper.gif")
     >>> _info(im)
     ('GIF', 'P', (128, 128))
-    >>> _info(Image.open(os.path.join(ROOT, "Tests/images/hopper.ppm")))
+    >>> _info(Image.open("Tests/images/hopper.ppm"))
     ('PPM', 'RGB', (128, 128))
     >>> try:
-    ...  _info(Image.open(os.path.join(ROOT, "Tests/images/hopper.jpg")))
+    ...  _info(Image.open("Tests/images/hopper.jpg"))
     ... except IOError as v:
     ...  print(v)
     ('JPEG', 'RGB', (128, 128))
@@ -64,7 +56,7 @@ def testimage():
     PIL doesn't actually load the image data until it's needed,
     or you call the "load" method:
 
-    >>> im = Image.open(os.path.join(ROOT, "Tests/images/hopper.ppm"))
+    >>> im = Image.open("Tests/images/hopper.ppm")
     >>> print(im.im) # internal image attribute
     None
     >>> a = im.load()
@@ -74,7 +66,7 @@ def testimage():
     You can apply many different operations on images.  Most
     operations return a new image:
 
-    >>> im = Image.open(os.path.join(ROOT, "Tests/images/hopper.ppm"))
+    >>> im = Image.open("Tests/images/hopper.ppm")
     >>> _info(im.convert("L"))
     (None, 'L', (128, 128))
     >>> _info(im.copy())
@@ -180,25 +172,16 @@ if __name__ == "__main__":
         ("freetype2", "FREETYPE2"),
         ("littlecms2", "LITTLECMS2"),
         ("webp", "WEBP"),
-        ("transp_webp", "Transparent WEBP")
-    ]:
-        supported = features.check_module(name)
-
-        if supported is None:
-            # A method was being tested, but the module required
-            # for the method could not be correctly imported
-            pass
-        elif supported:
-            print("---", feature, "support ok")
-        else:
-            print("***", feature, "support not installed")
-    for name, feature in [
+        ("transp_webp", "WEBP Transparency"),
+        ("webp_mux", "WEBPMUX"),
+        ("webp_anim", "WEBP Animation"),
         ("jpg", "JPEG"),
         ("jpg_2000", "OPENJPEG (JPEG2000)"),
         ("zlib", "ZLIB (PNG/ZIP)"),
-        ("libtiff", "LIBTIFF")
+        ("libtiff", "LIBTIFF"),
+        ("raqm", "RAQM (Bidirectional Text)")
     ]:
-        if features.check_codec(name):
+        if features.check(name):
             print("---", feature, "support ok")
         else:
             print("***", feature, "support not installed")
